# -*- coding: latin-1 -*-
#    QUENLIG: Questionnaire en ligne (Online interactive tutorial)
#    Copyright (C) 2008 Thierry EXCOFFIER, Olivier GLCK, Universite de Lyon
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#    Contact: Thierry.EXCOFFIER@bat710.univ-lyon1.fr
#

from questions import *
from check import *

add(name="zone",
    required=["intro:avantages", "intro:inconvnients"],
    question = "Quelle est votre zone DNS&nbsp;?",
    tests = (good_if_contains(''),),
    )

add(name="plage",
    required=["intro:avantages", "intro:inconvnients"],
    question = "Quelle est votre plage d'adresse IP&nbsp;?",
    tests = (good_if_contains(''),),
    )

add(name="named.conf",
    required=["zone", "plage"],
    question = """Que modifiez-vous dans le fichier <tt>named.conf</tt>&nbsp;?
    <p>
    Vous aurez 0 points si vous dpassez 10 lignes dans la rponse.
    """,
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="zones",
    required=["zone", "plage"],
    question = """Que modifiez-vous dans les fichiers de zone. Donnez uniquement pour chaque fichier de zone un ou deux exemples de chaque type de RR (<em>Resource Record</em>) utilis.
    <p>
    Vous aurez 0 points si vous dpassez 30 lignes dans la rponse.
    """,
    nr_lines = 30,
    tests = (good_if_contains(''),),
    )

add(name="creation zone",
    required=["zones"],
    question = "Expliquez comment vous gnrez les fichiers de zone : algorithme ou programme, ...",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="noms logiques",
    required=["zones"],
    question = """Quels sont les principes des <em>noms plus parlants</em>.
    <p>Indiquez les modifications apportes aux fichiers de configuration.
    <p>
    Vous aurez 0 points si vous dpassez 10 lignes dans la rponse.
    """,
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="client",
    required=["noms logiques"],
    question = "Comment configurez-vous un client DNS dans votre zone&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="dig",
    required=["client"],
    question = "Indiquez la commande <tt>dig</tt>@server, le nom et le type. Donnez la syntaxe quivalente avec la commande <tt>host</tt>",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="connue",
    required=["dig"],
    question = "Quelle ligne de commande permet de vrifier que votre machine cliente est bien enregistre dans le serveur DNS de votre zone&nbsp;?",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="inverse",
    required=["dig"],
    question = "Quelle ligne de commande permet de vrifier que votre machine cliente est bien enregistre dans la zone inverse&nbsp;?",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="serveurs",
    required=["dig"],
    question = "Quelle ligne de commande permet de lister les serveurs primaire et secondaires de votre zone&nbsp;?",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="contact",
    required=["dig"],
    question = "Quelle ligne de commande permet de connatre l'adresse e-mail de l'administrateur de la zone&nbsp;?",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="alias",
    required=["dig"],
    question = "Quelle ligne de commande permet de lister tous les alias de votre zone (et uniquement eux)&nbsp;?",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="tout",
    required=["dig"],
    question = "Quelle ligne de commande permet de connatre l'ensemble des enregistrements rfrencs par votre serveur DNS&nbsp;?",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="commentaire",
    required=["connue", "inverse", "serveurs", "contact", "alias", "tout"],
    question = "Commentaires sur le rsultat de ces commandes&nbsp;:",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

# 5.3

add(name="racine",
    required=["commentaire"],
    question = "Passerelles entre les zones DNS. Faites un schma reprsentant la configuration mise en place. Indiquez zones DNS, machines et adresses IP.",
    nr_lines = 20,
    tests = (good_if_contains(''),),
    )

add(name="imaginaire",
    required=["commentaire"],
    question = "Que se passe-t-il quand on fait une requte sur une machine imaginaire (non rfrence), donnez la commande et les commentaires&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="autre",
    required=["commentaire"],
    question = "Que se passe-t-il quand on fait une requte sur une machine rfrence sur un autre serveur DNS, donnez la commande et les commentaires&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )


add(name="directe",
    required=["commentaire"],
    question = "Que se passe-t-il quand on fait une requte sur une machine rfrence sur un autre serveur DNS avec interrogation directe du serveur DNS de source autorise de l'autre salle. Donnez la commande et les commentaires&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="trace",
    required=["imaginaire", "autre", "directe"],
    question = "Refaites les commandes avec <tt>+trace</tt>, conclusions&nbsp;?",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )


add(name="racines",
    required=["trace"],
    question = """Votre serveur racine primaire ou secondaire, adresse IP et modifications dans <tt>named.conf</tt>.
    <p>
    Vous aurez 0 points si vous dpassez 10 lignes dans la rponse.
    """,
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="racines zone",
    required=["racines"],
    question = """Contenu du fichier de la zone racine&nbsp;:
    <p>
    Vous aurez 0 points si vous dpassez 20 lignes dans la rponse.
    """,
    nr_lines = 20,
    tests = (good_if_contains(''),),
    )

# copi coll

add(name="imaginaire2",
    required=["racines"],
    question = "Machine imaginaire (schma + commentaires)&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="autre2",
    required=["racines"],
    question = "Machine rfrence sur un autre serveur DNS (schma + commentaires)&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="directe2",
    required=["racines"],
    question = "Machine rfrence sur un autre serveur DNS (schma + commentaires) avec interrogation directe du serveur DNS de source autorise de l'autre salle&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="dbranche",
    required=["imaginaire2", "autre2", "directe2"],
    question = "Que se passe t-il si vous dbranchez le cble rseau du serveur racine primaire&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

#

add(name="resolv",
    required=["racines"],
    question = "Vos modifications dans le fichier <tt>/etc/resolv.conf</tt>&nbsp;:",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

add(name="ping",
    required=["resolv"],
    question = "<tt>ping m138</tt> et notez l'adresse IP correspondante&nbsp;:",
    tests = (good_if_contains(''),),
    )

add(name="ping2",
    required=["resolv"],
    question = "Changez l'ordre des suffixes et refaites <tt>ping m138</tt> et notez l'adresse IP correspondante&nbsp;:",
    tests = (good_if_contains(''),),
    )

add(name="diffrence",
    required=["ping", "ping2"],
    question = "Expliquez&nbsp;:",
    nr_lines = 5,
    tests = (good_if_contains(''),),
    )

#


add(name="exprience 1",
    required=["resolv"],
    question = "Mises  jour des serveurs secondaires (racines dans votre cas).<p>Exprience 1&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="exprience 2",
    required=["resolv"],
    question = "Mises  jour des serveurs secondaires (racines dans votre cas).<p>Exprience 2&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

# 5.4

add(name="wireshark",
    required=["resolv"],
    question = "Visualiser avec <tt>wireshark</tt>... Que constatez-vous&nbsp;? Expliquez&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="nouvelle",
    required=["resolv"],
    question = "Intgration d'un nouvel utilisateur et de sa machine dans votre rseau, indiquez le nom de machine, le login et les oprations  effectuer&nbsp;:",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )

add(name="totale",
    required=["nouvelle"],
    question = "Configurez une machine qui soit  la fois client NFS, client NIS, client LDAP et client DNS. Comment testez-vous que tout fonctionne correctement&nbsp;?",
    nr_lines = 10,
    tests = (good_if_contains(''),),
    )




















